@@ -38,6 +38,7 @@ nepim_global_t nepim_global = {
   4096,    /* udp_write_size */
   4096,    /* udp_read_size */
   "1234",  /* portname */
+  0,       /* no_inet4 */
   0,       /* no_inet6 */
   250000,  /* write_delay (usec, bit_rate > 0) */
   100,     /* listen_backlog */
@@ -55,6 +56,7 @@ nepim_global_t nepim_global = {
   1000,    /* udp_win_max */
   -1,      /* win_recv */
   -1,      /* win_send */
+  1,       /* udp_require_greet_reply (boolean, client) */
 
   0, /* oop source */
   0  /* source interface */
