@@ -45,6 +45,7 @@ struct nepim_global_t {
   int         udp_write_size;
   int         udp_read_size;
   const char *portname;
+  int         no_inet4;
   int         no_inet6;
   susec_t     write_delay;
   int         listen_backlog;
@@ -53,15 +54,16 @@ struct nepim_global_t {
   char       *join_list;
   int         ttl;
   int         mcast_ttl;
-  susec_t     udp_greet_delay; /* usec */
+  susec_t     udp_greet_delay;         /* usec */
   int         max_greetings;
-  susec_t     udp_keepalive_timer; /* usec, receivers */
-  susec_t     udp_keepalive_delay; /* usec, non-senders */
-  int         udp_keepalive_require; /* boolean, receivers */
-  int         udp_keepalive_send; /* boolean, non-senders */
+  susec_t     udp_keepalive_timer;     /* usec, receivers */
+  susec_t     udp_keepalive_delay;     /* usec, non-senders */
+  int         udp_keepalive_require;   /* boolean, receivers */
+  int         udp_keepalive_send;      /* boolean, non-senders */
   int         udp_win_max;
   int         win_recv;
   int         win_send;
+  int         udp_require_greet_reply; /* boolean, client */
 
   oop_source_sys *oop_sys;
   oop_source     *oop_src;
