@@ -21,7 +21,7 @@ Boston, MA 02111-1307, USA.
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.22 2005/09/09 22:40:37 evertonm Exp $
+  $Id: main.c,v 1.25 2005/09/18 19:37:00 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -94,10 +94,12 @@ static void usage(FILE *out, const char *prog_name)
 	  "  -O size       maximum socket send buffer in bytes\n"
 	  "  -I size       maximum socket receive buffer in bytes\n"
 	  "  -6            disable IPv6\n"
+	  "  -4            disable IPv4\n"
 	  "client-only options:\n"
 	  "  -u            UDP mode (defaults to TCP)\n"
 	  "  -s            client-send simplex mode (defaults to server-send)\n"
 	  "  -d            duplex traffic (defaults to simplex)\n"
+	  "  -M            enable multicast-compatible options\n"
 	  "  -c host-list  client mode (defaults to server mode)\n"
 	  "  -n pipes      number of parallel pipes (defaults to %d)\n"
 	  "  -r bit-rate   upper bit rate limit (defaults to %s bps)\n"
@@ -174,6 +176,11 @@ int main(int argc, const char *argv[])
   for (i = 1; i < argc; ++i) {
     const char *arg = argv[i];
 
+    if (!strcmp(arg, "-4")) {
+      nepim_global.no_inet4 = 1;
+      continue;
+    }
+
     if (!strcmp(arg, "-6")) {
       nepim_global.no_inet6 = 1;
       continue;
@@ -278,6 +285,15 @@ int main(int argc, const char *argv[])
       continue;
     }
 
+    if (!strcmp(arg, "-M")) {
+      nepim_global.udp_mode                = 1; /* boolean */
+      nepim_global.simplex_client_send     = 1; /* boolean */
+      nepim_global.udp_keepalive_require   = 0; /* boolean */
+      nepim_global.udp_require_greet_reply = 0; /* boolean */
+      nepim_global.max_greetings           = 1; /* counter */
+      continue;
+    }
+
     if (!strcmp(arg, "-r")) {
       int bytes;
       ++i;
