@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: server.c,v 1.38 2005/09/12 23:41:41 evertonm Exp $ */
+/* $Id: server.c,v 1.39 2005/09/18 19:37:00 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -611,7 +611,7 @@ static int spawn_tcp_listener(const char *hostname, const char *portname)
 
   hints.ai_socktype = SOCK_STREAM;
   hints.ai_protocol = IPPROTO_TCP;
-  hints.ai_flags = AI_CANONNAME;
+  hints.ai_flags = AI_PASSIVE | AI_CANONNAME;
   hints.ai_family = PF_UNSPEC;
   hints.ai_addrlen = 0;
   hints.ai_addr = 0;
@@ -639,6 +639,9 @@ static int spawn_tcp_listener(const char *hostname, const char *portname)
     if (nepim_global.no_inet6 && (ai->ai_family == PF_INET6))
       continue;
 
+    if (nepim_global.no_inet4 && (ai->ai_family == PF_INET))
+      continue;
+
     sd = nepim_create_listener_socket(ai->ai_addr, ai->ai_addrlen,
 				      ai->ai_family, ai->ai_socktype, 
 				      ai->ai_protocol,
