@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: slot.c,v 1.24 2005/08/18 21:59:11 evertonm Exp $ */
+/* $Id: slot.c,v 1.25 2005/09/18 18:28:51 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -51,6 +51,32 @@ nepim_slot_t *nepim_slot_set_search(const nepim_slot_set_t *set, int index)
   return nepim_array_search(&set->array, index);
 }
 
+struct ctx_t {
+  const struct sockaddr *sa;
+  socklen_t len;
+};
+
+static int match_remote_addr(const void *context, const void *element)
+{
+  const struct ctx_t *ctx = context;
+  const nepim_slot_t *slot = element;
+
+  assert(ctx);
+
+  if (slot)
+    return !memcmp(&slot->session.remote, ctx->sa, ctx->len);
+
+  return 0;
+}
+
+nepim_slot_t *nepim_slot_set_search_remote(const nepim_slot_set_t *set,
+					   const struct sockaddr *addr,
+					   socklen_t len)
+{
+  struct ctx_t ctx = { addr, len };
+  return nepim_array_find(&set->array, match_remote_addr, &ctx);
+}
+
 int nepim_slot_find_free(nepim_slot_set_t *set)
 {
   return nepim_array_find_free(&set->array);
