@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: slot.h,v 1.21 2005/08/18 21:59:11 evertonm Exp $ */
+/* $Id: slot.h,v 1.22 2005/09/18 18:28:51 evertonm Exp $ */
 
 #ifndef NEPIM_SLOT_H
 #define NEPIM_SLOT_H
@@ -63,6 +63,9 @@ void nepim_slot_set_init(nepim_slot_set_t *set);
 
 nepim_slot_t *nepim_slot_set_get(const nepim_slot_set_t *set, int index);
 nepim_slot_t *nepim_slot_set_search(const nepim_slot_set_t *set, int index);
+nepim_slot_t *nepim_slot_set_search_remote(const nepim_slot_set_t *set,
+					   const struct sockaddr *addr,
+					   socklen_t len);
 
 int nepim_slot_find_free(nepim_slot_set_t *set);
 
