@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: udp_client.c,v 1.40 2005/09/12 23:41:41 evertonm Exp $ */
+/* $Id: udp_client.c,v 1.43 2005/09/18 19:37:00 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -320,8 +320,8 @@ static int slot_greet_write(nepim_slot_t *slot)
   opt.stat_interval         = nepim_global.stat_interval;
   opt.test_duration         = nepim_global.test_duration;
   opt.write_delay           = nepim_global.write_delay;
-  opt.udp_keepalive_send    = nepim_global.udp_keepalive_send;
-  opt.udp_keepalive_require = nepim_global.udp_keepalive_require;
+  opt.udp_keepalive_send    = nepim_global.udp_keepalive_require;
+  opt.udp_keepalive_require = nepim_global.udp_keepalive_send;
 
   buf_avail_len = sizeof(buf) - UDP_HEADER_LEN;
   assert(buf_avail_len > 0);
@@ -499,11 +499,26 @@ static void udp_write_greet(nepim_slot_t *slot)
   int result;
   int sd = slot->udp_sd;
 
+  assert(slot->client_writer_status == NEPIM_SLOT_CLIENT_GREET);
+
   /* stop writing */
   assert(slot->want_write == 1);
   cancel_slot_greet_writer(slot);
 
   if (slot->greetings_sent >= nepim_global.max_greetings) {
+
+    if (!nepim_global.udp_require_greet_reply) {
+
+      cancel_slot_greet_timer(slot);
+      soft_cancel_slot_greet_writer(slot);
+
+      slot->client_writer_status = NEPIM_SLOT_CLIENT_SEND;
+    
+      udp_slot_start(slot);
+
+      return;
+    }
+
     fprintf(stderr, 
 	    "%d %d-%d: max. greetings reached (%d/%d) - server not responding\n",
 	    sd, slot->index, slot->index_remote,
@@ -1036,6 +1051,9 @@ static int spawn_udp_connection(const char *hostname,
     if (nepim_global.no_inet6 && (ai->ai_family == PF_INET6))
       continue;
 
+    if (nepim_global.no_inet4 && (ai->ai_family == PF_INET))
+      continue;
+
     sd = nepim_connect_client_socket(ai->ai_addr, ai->ai_addrlen,
 				     ai->ai_family, ai->ai_socktype, 
 				     ai->ai_protocol,
@@ -1185,7 +1203,7 @@ void nepim_udp_clients(const char *host_list)
     /* 
        schedule periodic greetings 
        (until answer from server)
-     */
+    */
     session->tv_greet_rate = OOP_TIME_NOW;
     nepim_global.oop_src->on_time(nepim_global.oop_src,
 				  session->tv_greet_rate,
