@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: udp_server.c,v 1.60 2005/09/02 21:57:58 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.62 2005/09/18 19:37:00 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -816,6 +816,16 @@ static void *on_udp_segment(oop_source *src, int sd,
   {
     nepim_slot_t *slot = nepim_slot_set_search(&slots, hdr.dst_slot);
 
+    /*
+      multicast client can't know the server slot index,
+      since the multicast server never send replies.
+      so, the server finds the slot by socket address.
+    */
+    if (!slot)
+      slot = nepim_slot_set_search_remote(&slots, 
+					  (const struct sockaddr *) &from,
+					  fromlen);
+
     if (!slot) {
       fprintf(stderr,
 	      "%d: recvfrom: unknown local slot: %d\n",
@@ -862,7 +872,7 @@ int nepim_udp_listener(const char *hostname, const char *portname,
 
   hints.ai_socktype = SOCK_DGRAM;
   hints.ai_protocol = IPPROTO_UDP;
-  hints.ai_flags = AI_CANONNAME;
+  hints.ai_flags = AI_PASSIVE | AI_CANONNAME;
   hints.ai_family = PF_UNSPEC;
   hints.ai_addrlen = 0;
   hints.ai_addr = 0;
@@ -890,6 +900,9 @@ int nepim_udp_listener(const char *hostname, const char *portname,
     if (nepim_global.no_inet6 && (ai->ai_family == PF_INET6))
       continue;
 
+    if (nepim_global.no_inet4 && (ai->ai_family == PF_INET))
+      continue;
+
     sd = nepim_create_socket(ai->ai_addr, ai->ai_addrlen,
 			     ai->ai_family, ai->ai_socktype, 
 			     ai->ai_protocol,
